@@ -1,4 +1,9 @@
-import re
+import sys
+
+if sys.version_info >= (3, 10):
+    from importlib.metadata import version
+else:
+    from importlib_metadata import version
 
 needs_sphinx = "2.1"
 extensions = [
@@ -9,9 +14,8 @@ extensions = [
 ]
 master_doc = "index"
 project = "sphinxcontrib-bibtex"
-copyright = "2011-2023, Matthias C. M. Troffaes"
-with open("../src/sphinxcontrib/bibtex/__init__.py", "rt") as version_file:
-    release = re.search('"version": "(.+)"', version_file.read()).group(1)
+copyright = "2011-2024, Matthias C. M. Troffaes"
+release = version("sphinxcontrib-bibtex")
 version = ".".join(release.split(".")[:2])
 exclude_patterns = ["_build"]
 pygments_style = "sphinx"
