@@ -1,11 +1,11 @@
 """
-    Domain for footnote citations.
+Domain for footnote citations.
 
-    .. autoclass:: BibtexFootDomain
-        :members:
+.. autoclass:: BibtexFootDomain
+    :members:
 """
 
-from typing import TYPE_CHECKING, Dict, List, Tuple
+from typing import TYPE_CHECKING, AbstractSet, Dict, List, Tuple
 
 import docutils.nodes
 import docutils.utils
@@ -65,7 +65,7 @@ class BibtexFootDomain(Domain):
                 header, "foot_bibliography_header"
             )
 
-    def merge_domaindata(self, docnames: List[str], otherdata: Dict) -> None:
+    def merge_domaindata(self, docnames: AbstractSet[str], otherdata: Dict) -> None:
         """Merge in data regarding *docnames* from domain data
         inventory *otherdata*.
 
@@ -82,7 +82,7 @@ class BibtexFootDomain(Domain):
         target: str,
         node: "pending_xref",
         contnode: docutils.nodes.Element,
-    ) -> List[Tuple[str, docutils.nodes.Element]]:
+    ) -> List[Tuple[str, docutils.nodes.reference]]:
         """Resolve the pending reference *node* with the given *target*,
         where the reference comes from an "any" role.
 
