@@ -1,15 +1,14 @@
 from dataclasses import dataclass, field
-import sphinxcontrib.bibtex.plugin
 
+import sphinxcontrib.bibtex.plugin
 from sphinxcontrib.bibtex.style.referencing import BracketStyle
-from sphinxcontrib.bibtex.style.referencing.author_year \
-    import AuthorYearReferenceStyle
+from sphinxcontrib.bibtex.style.referencing.author_year import AuthorYearReferenceStyle
 
 
 def bracket_style() -> BracketStyle:
     return BracketStyle(
-        left='(',
-        right=')',
+        left="(",
+        right=")",
     )
 
 
@@ -23,11 +22,11 @@ class MyReferenceStyle(AuthorYearReferenceStyle):
 
 
 sphinxcontrib.bibtex.plugin.register_plugin(
-    'sphinxcontrib.bibtex.style.referencing',
-    'author_year_round', MyReferenceStyle)
+    "sphinxcontrib.bibtex.style.referencing", "author_year_round", MyReferenceStyle
+)
 
 
-extensions = ['sphinxcontrib.bibtex']
-exclude_patterns = ['_build']
-bibtex_bibfiles = ['refs.bib']
-bibtex_reference_style = 'author_year_round'
+extensions = ["sphinxcontrib.bibtex"]
+exclude_patterns = ["_build"]
+bibtex_bibfiles = ["refs.bib"]
+bibtex_reference_style = "author_year_round"
